"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const index_1 = require("../lib/index");
describe('greeter function test', () => {
    it('Test file not found', () => {
        const sp = new index_1.SauceParser();
        const fileName = '/no/such/file';
        const func = () => sp.parse(fileName);
        chai_1.expect(func).to.throw(`File ${fileName} not found`);
    });
    it('Test file without SAUCE', () => {
        const sp = new index_1.SauceParser();
        const result = sp.parse(__dirname + '/files/FILE_ID.DIZ');
        // tslint:disable-next-line:no-unused-expression
        chai_1.expect(result).to.be.null;
    });
    it('Test SAUCE in ans', () => {
        const sp = new index_1.SauceParser();
        const result = sp.parse(__dirname + '/files/us-crypt.ans');
        // tslint:disable-next-line:no-unused-expression
        chai_1.expect(result).to.be.not.null;
        chai_1.expect(result.id).to.equal('SAUCE');
        chai_1.expect(result.version).to.equal('00');
        chai_1.expect(result.title).to.equal('the crypt');
        chai_1.expect(result.author).to.equal('the knight');
        chai_1.expect(result.group).to.equal('fuel');
        chai_1.expect(result.comments.length).to.equal(1);
        chai_1.expect(result.comments[0]).to.equal('pic by The Knight - font by Nail');
        chai_1.expect(result.dataType.code).to.equal(1);
        chai_1.expect(result.dataType.name).to.equal('Character');
        chai_1.expect(result.dataType.description).to.equal('A character based file');
        chai_1.expect(result.date.getDate()).to.equal(31);
        chai_1.expect(result.date.getMonth()).to.equal(6);
        chai_1.expect(result.date.getFullYear()).to.equal(2017);
        chai_1.expect(result.fileSize).to.equal(14284);
        chai_1.expect(result.fileType).to.equal(1);
        chai_1.expect(result.flags).to.equal(18);
        chai_1.expect(result.tInfo1).to.equal(80);
        chai_1.expect(result.tInfo2).to.equal(55);
        chai_1.expect(result.tInfo3).to.equal(0);
        chai_1.expect(result.tInfo4).to.equal(0);
        chai_1.expect(result.tInfoS).to.equal('IBM VGA');
    });
    it('Test SAUCE in nfo', () => {
        const sp = new index_1.SauceParser();
        const result = sp.parse(__dirname + '/files/ACIDVIEW.NFO');
        // tslint:disable-next-line:no-unused-expression
        chai_1.expect(result).to.be.not.null;
        chai_1.expect(result.id).to.equal('SAUCE');
        chai_1.expect(result.version).to.equal('00');
        chai_1.expect(result.title).to.equal('ACiD View Documentation');
        chai_1.expect(result.author).to.equal('RaD Man');
        chai_1.expect(result.group).to.equal('ACiD Productions');
        chai_1.expect(result.comments.length).to.equal(0);
        chai_1.expect(result.dataType.code).to.equal(1);
        chai_1.expect(result.dataType.name).to.equal('Character');
        chai_1.expect(result.dataType.description).to.equal('A character based file');
        chai_1.expect(result.date.getDate()).to.equal(1);
        chai_1.expect(result.date.getMonth()).to.equal(6);
        chai_1.expect(result.date.getFullYear()).to.equal(1996);
        chai_1.expect(result.fileSize).to.equal(51349);
        chai_1.expect(result.fileType).to.equal(1);
        chai_1.expect(result.flags).to.equal(0);
        chai_1.expect(result.tInfo1).to.equal(80);
        chai_1.expect(result.tInfo2).to.equal(1271);
        chai_1.expect(result.tInfo3).to.equal(0);
        chai_1.expect(result.tInfo4).to.equal(0);
        chai_1.expect(result.tInfoS).to.equal('');
    });
});
